pub type MLKEM768 = MLKEM<MLKEM768_PK_LEN, MLKEM768_SK_LEN, MLKEM768_CT_LEN, MLKEM_SS_LEN, MLKEM768PublicKey, MLKEM768PrivateKey, MLKEM768_k, MLKEM768_ETA1, MLKEM768_DU, MLKEM768_DV, MLKEM768_LAMBDA>;Expand description
The ML-KEM-768 algorithm.
Aliased Type
pub struct MLKEM768 { /* private fields */ }Trait Implementations
Sourceimpl Algorithm for MLKEM768
impl Algorithm for MLKEM768
Sourceconst ALG_NAME: &'static str = ML_KEM_768_NAME
const ALG_NAME: &'static str = ML_KEM_768_NAME
String name for the algorithm, used consistently across the library.
Sourceconst MAX_SECURITY_STRENGTH: SecurityStrength = SecurityStrength::_192bit
const MAX_SECURITY_STRENGTH: SecurityStrength = SecurityStrength::_192bit
Maximum security strength supported by the algorithm.
In other words, this algorithm can produce outputs up to this security strength,
but may produce outputs with lower security strength, for example, if asked to truncate.